pub enum VtxError {
DatabaseError(String),
SerializationError(String),
AuthDenied(u16),
PermissionDenied(String),
NotFound(String),
Internal(String),
}Expand description
Plugin runtime error type (unified error model).
Defines all known errors that may occur during plugin execution. All errors support serialization and can be used for HTTP responses or log transmission.
Variants
DatabaseError(String)
Underlying database error (e.g., SQL execution failure, constraint conflicts).
SerializationError(String)
Serialization or deserialization failure (e.g., JSON format mismatch).
AuthDenied(u16)
Authentication failed (includes suggested HTTP status code, e.g., 401 / 403).
PermissionDenied(String)
Insufficient permissions (e.g., attempting a write operation in a read-only environment).
NotFound(String)
Resource not found (e.g., file, video, or user not found).
Internal(String)
Internal plugin logic error (fallback type).
Implementations